==> church_of_jesus_christ_api-0.2.3.tar.gz: church_of_jesus_christ_api-0.2.3/doc/source/JSON_schemas/get_unit_statistics-schema.md <==
{
  adultFemaleRecentConverts: int,
  adultFemaleRecentConvertsIndividualIds: list,
  adultMaleRecentConverts: int,
  adultMaleRecentConvertsIndividualIds: list,
  adults: int,
  adultsIndividualIds: [
    int
  ],
  baptizedNotConfirmed: int,
  baptizedNotConfirmedIndividualIds: list,
  beehive: int,
  beehiveIndividualIds: [
    int
  ],
  children: int,
  childrenAge8to11RecentConverts: int,
  childrenAge8to11RecentConvertsIndividualIds: list,
  childrenIndividualIds: [
    int
  ],
  deacons: int,
  deaconsIndividualIds: [
    int
  ],
  elders: int,
  eldersIndividualIds: [
    int
  ],
  endowedAdults: int,
  endowedAdultsIndividualIds: list,
  endowedWithRecommend: int,
  endowedWithRecommendIndividualIds: list,
  endowedWithoutRecommend: int,
  endowedWithoutRecommendIndividualIds: list,
  highPriests: int,
  highPriestsIndividualIds: [
    int
  ],
  households: int,
  householdsIndividualIds: [
    int
  ],
  householdsWithChildren: int,
  householdsWithChildrenIndividualIds: [
    int
  ],
  householdsWithSingleParentAndYouthOrChildren: int,
  householdsWithSingleParentAndYouthOrChildrenIndividualIds: [
    int
  ],
  householdsWithYouth: int,
  householdsWithYouthIndividualIds: [
    int
  ],
  householdsWithoutMelchizedekPriesthoodHolder: int,
  householdsWithoutMelchizedekPriesthoodHolderIndividualIds: [
    int
  ],
  individualsNotIncluded: int,
  individualsNotIncludedIndividualIds: [
    int
  ],
  infants: int,
  infantsIndividualIds: [
    int
  ],
  invalidBirthdate: int,
  invalidBirthdateIndividualIds: list,
  laurels: int,
  laurelsIndividualIds: [
    int
  ],
  marriedAdults: int,
  marriedAdultsIndividualIds: [
    int
  ],
  membersOfRecordAge9OrOlder: int,
  membersOfRecordAge9OrOlderIndividualIds: [
    int
  ],
  men: int,
  menIndividualIds: [
    int
  ],
  miaMaids: int,
  miaMaidsIndividualIds: [
    int
  ],
  ordainedRecentConverts: int,
  ordainedRecentConvertsIndividualIds: list,
  priests: int,
  priestsIndividualIds: [
    int
  ],
  prospectiveElders: int,
  prospectiveEldersIndividualIds: [
    int
  ],
  recentConverts: int,
  recentConvertsEligibleForOrdination: int,
  recentConvertsEligibleForOrdinationIndividualIds: list,
  recentConvertsIndividualIds: list,
  shortUnitName: NoneType,
  singleAdults: int,
  singleAdultsIndividualIds: [
    int
  ],
  teachers: int,
  teachersIndividualIds: [
    int
  ],
  totalMembers: int,
  totalMembersIndividualIds: [
    int
  ],
  unitName: NoneType,
  unitNumber: int,
  unitType: NoneType,
  unordainedRecentConverts: int,
  unordainedRecentConvertsIndividualIds: list,
  women: int,
  womenIndividualIds: [
    int
  ],
  youngMen: int,
  youngMenIndividualIds: [
    int
  ],
  youngMenRecentConverts: int,
  youngMenRecentConvertsIndividualIds: list,
  youngSingleAdults: int,
  youngSingleAdultsIndividualIds: [
    int
  ],
  youngWomen: int,
  youngWomen12_13: int,
  youngWomen12_13IndividualIds: [
    int
  ],
  youngWomen14_15: int,
  youngWomen14_15IndividualIds: [
    int
  ],
  youngWomen16_17: int,
  youngWomen16_17IndividualIds: [
    int
  ],
  youngWomenIndividualIds: [
    int
  ],
  youngWomenRecentConverts: int,
  youngWomenRecentConvertsIndividualIds: list
}

==> church_of_jesus_christ_api-0.2.8.tar.gz: church_of_jesus_christ_api-0.2.8/doc/source/JSON_schemas/get_unit_statistics-schema.md <==
{
  adultFemaleRecentConverts: int,
  adultFemaleRecentConvertsIndividualIds: list,
  adultMaleRecentConverts: int,
  adultMaleRecentConvertsIndividualIds: list,
  adults: int,
  adultsIndividualIds: [
    int
  ],
  baptizedNotConfirmed: int,
  baptizedNotConfirmedIndividualIds: list,
  beehive: int,
  beehiveIndividualIds: [
    int
  ],
  children: int,
  childrenAge8to11RecentConverts: int,
  childrenAge8to11RecentConvertsIndividualIds: [
    int
  ],
  childrenIndividualIds: [
    int
  ],
  deacons: int,
  deaconsIndividualIds: [
    int
  ],
  elders: int,
  eldersIndividualIds: [
    int
  ],
  endowedAdults: int,
  endowedAdultsIndividualIds: [
    int
  ],
  endowedWithRecommend: int,
  endowedWithRecommendIndividualIds: [
    int
  ],
  endowedWithoutRecommend: int,
  endowedWithoutRecommendIndividualIds: [
    int
  ],
  highPriests: int,
  highPriestsIndividualIds: [
    int
  ],
  households: int,
  householdsIndividualIds: [
    int
  ],
  householdsWithChildren: int,
  householdsWithChildrenIndividualIds: [
    int
  ],
  householdsWithSingleParentAndYouthOrChildren: int,
  householdsWithSingleParentAndYouthOrChildrenIndividualIds: [
    int
  ],
  householdsWithYouth: int,
  householdsWithYouthIndividualIds: [
    int
  ],
  householdsWithoutMelchizedekPriesthoodHolder: int,
  householdsWithoutMelchizedekPriesthoodHolderIndividualIds: [
    int
  ],
  individualsNotIncluded: int,
  individualsNotIncludedIndividualIds: [
    int
  ],
  infants: int,
  infantsIndividualIds: [
    int
  ],
  invalidBirthdate: int,
  invalidBirthdateIndividualIds: list,
  laurels: int,
  laurelsIndividualIds: [
    int
  ],
  marriedAdults: int,
  marriedAdultsIndividualIds: [
    int
  ],
  membersOfRecordAge9OrOlder: int,
  membersOfRecordAge9OrOlderIndividualIds: [
    int
  ],
  men: int,
  menIndividualIds: [
    int
  ],
  miaMaids: int,
  miaMaidsIndividualIds: [
    int
  ],
  ordainedRecentConverts: int,
  ordainedRecentConvertsIndividualIds: [
    int
  ],
  priests: int,
  priestsIndividualIds: [
    int
  ],
  prospectiveElders: int,
  prospectiveEldersIndividualIds: [
    int
  ],
  recentConverts: int,
  recentConvertsEligibleForOrdination: int,
  recentConvertsEligibleForOrdinationIndividualIds: [
    int
  ],
  recentConvertsIndividualIds: [
    int
  ],
  shortUnitName: NoneType,
  singleAdults: int,
  singleAdultsIndividualIds: [
    int
  ],
  teachers: int,
  teachersIndividualIds: [
    int
  ],
  totalMembers: int,
  totalMembersIndividualIds: [
    int
  ],
  unitName: NoneType,
  unitNumber: int,
  unitType: NoneType,
  unordainedRecentConverts: int,
  unordainedRecentConvertsIndividualIds: list,
  women: int,
  womenIndividualIds: [
    int
  ],
  youngMen: int,
  youngMenIndividualIds: [
    int
  ],
  youngMenRecentConverts: int,
  youngMenRecentConvertsIndividualIds: [
    int
  ],
  youngSingleAdults: int,
  youngSingleAdultsIndividualIds: [
    int
  ],
  youngWomen: int,
  youngWomen12_13: int,
  youngWomen12_13IndividualIds: [
    int
  ],
  youngWomen14_15: int,
  youngWomen14_15IndividualIds: [
    int
  ],
  youngWomen16_17: int,
  youngWomen16_17IndividualIds: [
    int
  ],
  youngWomenIndividualIds: [
    int
  ],
  youngWomenRecentConverts: int,
  youngWomenRecentConvertsIndividualIds: list
}
